summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_remote_scheduler.py
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2017-04-08 14:06:35 +0200
committerHolger Levsen <holger@layer-acht.org>2017-04-08 14:06:35 +0200
commit9d1a395c73879712b8ca9c226411a983b3b39437 (patch)
treef61b617896aff89f4f3fe23e8e79d2a01b75c3a2 /bin/reproducible_remote_scheduler.py
parent125e5c48116a83e939bba49799cd05dbe7c6f848 (diff)
downloadjenkins.debian.net-9d1a395c73879712b8ca9c226411a983b3b39437.tar.xz
Revert "reproducible Debian: temporarily raise the personal daily scheduling limit to 2200"
This reverts commit 1ba9403bae9f1de9a6b071ba40e461fa93ee4ca7.
Diffstat (limited to 'bin/reproducible_remote_scheduler.py')
-rwxr-xr-xbin/reproducible_remote_scheduler.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_remote_scheduler.py b/bin/reproducible_remote_scheduler.py
index 96a071b5..cd1eaad6 100755
--- a/bin/reproducible_remote_scheduler.py
+++ b/bin/reproducible_remote_scheduler.py
@@ -212,7 +212,7 @@ date = (now - time_delta).strftime('%Y-%m-%d %H:%M')
log.debug('date_scheduled = ' + date + ' time_delta = ' + str(time_delta))
# a single person can't schedule more than 2200 packages in the same day; this
# is actually easy to bypass, but let's give some trust to the Debian people
query = """SELECT count(*) FROM manual_scheduler
WHERE requester = '{}' AND date_request > '{}'"""
@@ -221,7 +221,7 @@ try:
except IndexError:
amount = 0
log.debug(requester + ' already scheduled ' + str(amount) + ' packages today')
-if amount + len(ids) > 2200 and not local:
+if amount + len(ids) > 200 and not local:
log.error(bcolors.FAIL + 'You have exceeded the maximum number of manual ' +
'reschedulings allowed for a day. Please ask in ' +
'#debian-reproducible if you need to schedule more packages.' +
@@ -212,7 +212,7 @@ date = (now - time_delta).strftime('%Y-%m-%d %H:%M')
log.debug('date_scheduled = ' + date + ' time_delta = ' + str(time_delta))
-# a single person can't schedule more than 2200 packages in the same day; this
+# a single person can't schedule more than 200 packages in the same day; this
# is actually easy to bypass, but let's give some trust to the Debian people
query = """SELECT count(*) FROM manual_scheduler